/* This is for emacs: -*-Mode: C++;-*- */
#if !defined(__INC_WARNING_H)
#define __INC_WARNING_H

#include <string>

#include "gql++/exception.h"

namespace GQL
{
  
class SQLWarning : public SQLException
{
  public:
    SQLWarning(const std::string& str = std::string(),
               const std::string& state = std::string(),
               int err = 0)
        : SQLException(str, state, err) { }
};

}

#endif
